# -*- coding: utf-8 -*-

import uuid
from datetime import datetime

from zeep import Client, Settings

settings = Settings(strict=False, xml_huge_tree=True)
client = Client('http://127.0.0.1:34012/?wsdl', settings=settings)

# Авторизация
flt = {'login': 'admin', 'pass': ''}
response = client.service.Login('admin', '')
print('Login response:\n', response)

# добавить агента
agent = client.get_type('ns0:soapAgent')
agent = agent(descr='agent example', type=4, id=0)
val = client.get_type('ns0:soapAgentFull')
val = val(agent=agent)
agent_id = client.service.insupdAgent(**{'isInsert': 1, 'val': val})
print('Insert agent:\n', agent_id)

# добавить пользователя
acc = client.get_type('ns0:soapAccount')
acc_data = {
    'uid': 0,
    'type': 2,
    'login': 'acc%s' % uuid.uuid4().hex,
    'pass': 'acc',
    'name': 'acc example'
}
acc = acc(**acc_data)
val = client.get_type('ns0:soapAccountFull')
val = val(account=acc)
acc_id = client.service.insupdAccount(**{'isInsert': 1, 'val': val})
print('Insert account:\n', acc_id)

# добавить договор
val = client.get_type('ns0:soapAgreement')
val = val(uid=acc_id, number='agrm%s' % uuid.uuid4().hex, agrmid=0, operid=0,
          curid=0)
agrm_id = client.service.insupdAgreement(**{'isInsert': 1, 'val': val})
print('Insert agreement:\n', agrm_id)

# добавить учётную запись
vg = client.get_type('ns0:soapVgroup')
vg = vg(agrmid=agrm_id, id=agent_id, uid=acc_id, vgid=0)
val = client.get_type('ns0:soapVgroupFull')
val = val(vgroup=vg)
vg_id = client.service.insupdVgroup(**{'isInsert': 1, 'val': val})
print('Insert vgroup:\n', vg_id)

# получить договор
flt = client.get_type('ns0:soapFilter')
flt = flt(agrmid=agrm_id)
response = client.service.getAgreements(flt)
print('getAgreements response:\n', response)

# получить учётные записи по договору
response = client.service.getVgroups(flt)
print('getVgroups response:\n', response)

# обновить данные учётной записи (описание)
vg = client.get_type('ns0:soapVgroup')
vg = vg(agrmid=agrm_id, id=agent_id, uid=acc_id, vgid=vg_id,
        descr='updated vgroup data')
val = client.get_type('ns0:soapVgroupFull')
val = val(vgroup=vg)
vg_id = client.service.insupdVgroup(**{'isInsert': 0, 'val': val})
print('Update vgroup:\n', vg_id)

# получить учётную запись по идентификатору
flt = client.get_type('ns0:soapFilter')
flt = flt(vgid=vg_id)
response = client.service.getVgroups(flt)
print('getVgroups response:\n', response)

# задать курс
now = datetime.now().date().strftime('%Y-%m-%d')
val = client.get_type('ns0:soapRate')
val = val(curid=0, rate=20.0, date=now)
cur_id = client.service.updCurrencyRate(val)
print('updCurrencyRate response:\n', cur_id)

# платёж
val = client.get_type('ns0:soapPayment')
val = val(agrmid=agrm_id, amount=200.0, receipt='rec%s' % uuid.uuid4().hex, 
          comment="test payment", currid=cur_id)
payment_id = client.service.Payment(val)
print('Payment response:\n', payment_id)

# получить информацию о платеже
flt = client.get_type('ns0:soapFilter')
flt = flt(recordid=payment_id)
response = client.service.getPayments(flt)
print('getPayments response:\n', response)

# удалить учётную запись
response = client.service.delVgroup(id=vg_id)
print('Delete vgroup:\n', response)

# закрыть договор
response = client.service.closeAgreement(agrmid=agrm_id, closedate=now)
print('Close agreement:\n', response)

# удалить договор
response = client.service.delAgreement(agrmid=agrm_id)
print('Delete agreement:\n', response)

# удалить пользователя
response = client.service.delAccount(id=acc_id)
print('Delete account:\n', response)

# удалить агента
response = client.service.delAgent(id=agent_id)
print('Delete agent:\n', response)

response = client.service.Logout()
print('Logout response:\n', response)
